@@ -27,6 +27,12 @@ class Parse(_Parse):
         res = self._morph._inflect(self, required_grammemes)
         return None if not res else res[0]
 
+    def make_agree_with_number(self, num):
+        """
+        Inflects the word so that it agrees with ``num``
+        """
+        return self.inflect(self.tag.numeral_agreement_grammemes(num))
+
     @property
     def lexeme(self):
         """ A lexeme this form belongs to. """
