@@ -2,8 +2,12 @@
 from __future__ import absolute_import
 
 from .by_lookup import DictionaryAnalyzer
+
 from .by_analogy import (KnownPrefixAnalyzer, KnownSuffixAnalyzer,
                          UnknownPrefixAnalyzer)
+
 from .by_hyphen import (HyphenatedWordsAnalyzer, HyphenAdverbAnalyzer,
                         HyphenSeparatedParticleAnalyzer)
-from .by_shape import LatinAnalyzer, PunctuationAnalyzer, NumberAnalyzer
\ No newline at end of file
+
+from .by_shape import (LatinAnalyzer, PunctuationAnalyzer, NumberAnalyzer,
+                       RomanNumberAnalyzer)
\ No newline at end of file
